﻿// --------------------------------------------------------------------------------------------------------------------
// <copyright file="AudioEncodeRateType.cs" company="HandBrake Project (http://handbrake.fr)">
//   This file is part of the HandBrake source code - It may be used under the terms of the GNU General Public License.
// </copyright>
// <summary>
//   The audio encode rate type.
// </summary>
// --------------------------------------------------------------------------------------------------------------------

namespace HandBrake.Interop.Model.Encoding
{
    /// <summary>
    /// The audio encode rate type.
    /// </summary>
    public enum AudioEncodeRateType
	{
		Bitrate,
		Quality
	}
}
